import React, { useState } from "react";
import { Menu, X } from "lucide-react";

export default function Header() {
  const [mobileMenuOpen, setMobileMenuOpen] = useState(false);

  const scrollToSection = (sectionId: string) => {
    const element = document.getElementById(sectionId);
    if (element) {
      element.scrollIntoView({ behavior: "smooth" });
      setMobileMenuOpen(false);
    }
  };

  return (
    <header style={{
      background: 'linear-gradient(135deg, #1e40af 0%, #3b82f6 100%)',
      color: 'white',
      padding: '1rem 0',
      position: 'sticky',
      top: 0,
      zIndex: 1000,
      backdropFilter: 'blur(10px)',
      boxShadow: '0 4px 20px rgba(0, 0, 0, 0.1)'
    }}>
      <div className="container mx-auto px-4 max-w-6xl">
        <div className="flex justify-between items-center">
          <div style={{ display: 'flex', alignItems: 'center', gap: '1rem' }}>
            <img 
              src="/logo.png" 
              alt="TRUST Billing Connect" 
              className="header-logo"
              width="100"
              height="50"
              loading="lazy"
              style={{ height: '50px', width: '100px', objectFit: 'contain' }}
            />
            <h1 className="header-title" style={{ 
              fontSize: '1.5rem', 
              fontWeight: '700',
              textShadow: '0 2px 4px rgba(0,0,0,0.3)'
            }}>
              TRUST Billing Connect
            </h1>
          </div>
          <nav className="hidden md:flex space-x-2">
            <button
              onClick={() => window.location.href = '/ai-revenue-calculator'}
              className="shadow-sm"
              aria-label="Open AI revenue calculator"
              style={{
                padding: '0.75rem 1.5rem',
                borderRadius: '50px',
                background: 'rgba(255,255,255,0.1)',
                border: '1px solid rgba(255,255,255,0.2)',
                color: 'white',
                fontWeight: '600',
                transition: 'all 0.3s cubic-bezier(0.4, 0, 0.2, 1)',
                backdropFilter: 'blur(5px)'
              }}
              onMouseEnter={(e) => {
                e.currentTarget.style.background = 'rgba(255,255,255,0.2)';
                e.currentTarget.style.transform = 'translateY(-2px)';
                e.currentTarget.className = 'shadow-md';
              }}
              onMouseLeave={(e) => {
                e.currentTarget.style.background = 'rgba(255,255,255,0.1)';
                e.currentTarget.style.transform = 'translateY(0)';
                e.currentTarget.className = 'shadow-sm';
              }}
            >
              AI Calculator
            </button>
            <button
              onClick={() => scrollToSection("services")}
              className="shadow-sm"
              aria-label="Navigate to services section"
              style={{
                padding: '0.75rem 1.5rem',
                borderRadius: '50px',
                background: 'rgba(255,255,255,0.1)',
                border: '1px solid rgba(255,255,255,0.2)',
                color: 'white',
                fontWeight: '600',
                transition: 'all 0.3s cubic-bezier(0.4, 0, 0.2, 1)',
                backdropFilter: 'blur(5px)'
              }}
              onMouseEnter={(e) => {
                e.currentTarget.style.background = 'rgba(255,255,255,0.2)';
                e.currentTarget.style.transform = 'translateY(-2px)';
                e.currentTarget.className = 'shadow-md';
              }}
              onMouseLeave={(e) => {
                e.currentTarget.style.background = 'rgba(255,255,255,0.1)';
                e.currentTarget.style.transform = 'translateY(0)';
                e.currentTarget.className = 'shadow-sm';
              }}
            >
              Services
            </button>
            <button
              onClick={() => scrollToSection("about")}
              className="shadow-sm"
              aria-label="Navigate to about section"
              style={{
                padding: '0.75rem 1.5rem',
                borderRadius: '50px',
                background: 'rgba(255,255,255,0.1)',
                border: '1px solid rgba(255,255,255,0.2)',
                color: 'white',
                fontWeight: '600',
                transition: 'all 0.3s cubic-bezier(0.4, 0, 0.2, 1)',
                backdropFilter: 'blur(5px)'
              }}
              onMouseEnter={(e) => {
                e.currentTarget.style.background = 'rgba(255,255,255,0.2)';
                e.currentTarget.style.transform = 'translateY(-2px)';
                e.currentTarget.className = 'shadow-md';
              }}
              onMouseLeave={(e) => {
                e.currentTarget.style.background = 'rgba(255,255,255,0.1)';
                e.currentTarget.style.transform = 'translateY(0)';
                e.currentTarget.className = 'shadow-sm';
              }}
            >
              About Us
            </button>
            <button
              onClick={() => scrollToSection("contact")}
              className="shadow-sm"
              aria-label="Navigate to contact section"
              style={{
                padding: '0.75rem 1.5rem',
                borderRadius: '50px',
                background: 'rgba(255,255,255,0.1)',
                border: '1px solid rgba(255,255,255,0.2)',
                color: 'white',
                fontWeight: '600',
                transition: 'all 0.3s cubic-bezier(0.4, 0, 0.2, 1)',
                backdropFilter: 'blur(5px)'
              }}
              onMouseEnter={(e) => {
                e.currentTarget.style.background = 'rgba(255,255,255,0.2)';
                e.currentTarget.style.transform = 'translateY(-2px)';
                e.currentTarget.className = 'shadow-md';
              }}
              onMouseLeave={(e) => {
                e.currentTarget.style.background = 'rgba(255,255,255,0.1)';
                e.currentTarget.style.transform = 'translateY(0)';
                e.currentTarget.className = 'shadow-sm';
              }}
            >
              Contact
            </button>
          </nav>
          
          {/* Mobile Menu Button */}
          <button
            onClick={() => setMobileMenuOpen(!mobileMenuOpen)}
            className="md:hidden shadow-sm"
            aria-label={mobileMenuOpen ? "Close navigation menu" : "Open navigation menu"}
            style={{
              display: 'block',
              padding: '0.75rem',
              borderRadius: '50%',
              background: 'rgba(255,255,255,0.1)',
              border: '1px solid rgba(255,255,255,0.2)',
              color: 'white',
              transition: 'all 0.3s cubic-bezier(0.4, 0, 0.2, 1)',
              backdropFilter: 'blur(5px)'
            }}
          >
            {mobileMenuOpen ? (
              <X className="w-6 h-6" />
            ) : (
              <Menu className="w-6 h-6" />
            )}
          </button>
        </div>
        
        {/* Mobile Navigation */}
        {mobileMenuOpen && (
          <nav className="md:hidden mt-4 space-y-2">
            <button
              onClick={() => scrollToSection("services")}
              className="block text-white hover:text-blue-200 transition-colors font-medium py-2 w-full text-left"
            >
              Services
            </button>
            <button
              onClick={() => scrollToSection("about")}
              className="block text-white hover:text-blue-200 transition-colors font-medium py-2 w-full text-left"
            >
              About Us
            </button>
            <button
              onClick={() => scrollToSection("contact")}
              className="block text-white hover:text-blue-200 transition-colors font-medium py-2 w-full text-left"
            >
              Contact
            </button>
          </nav>
        )}
      </div>
    </header>
  );
}
